from urequest import urlopen


FEED = "http://api.xively.com/v2/feeds/436311059"

data="""\
{
  "version":"1.0.0",
   "datastreams" : [ {
        "id" : "sensor1",
        "current_value" : "150"
    }
  ]
}
"""
print(data)

f = urlopen(FEED + ".json?key=2ez3VN73MFbOEP96fZ4KVBBxRZ2pe64RUXhpbINb6qMJIQ4e", method="PUT", data=data)
print(str(f.read(), "utf-8"))



import time
from urequest import urlopen


FEED = "http://api.xively.com/v2/feeds/436311059"

t = time.time() - 2 * 3600
tstamp = time.strftime("%Y-%m-%dT%H:%M:00Z", int(t))
data="sensor1,%s,210\n" % tstamp
print(data)

f = urlopen(FEED + ".csv?key=2ez3VN73MFbOEP96fZ4KVBBxRZ2pe64RUXhpbINb6qMJIQ4e", method="PUT", data=data)
print(str(f.read(), "utf-8"))



import usocket

def urlopen(url, data=None):
    if data is not None and method=="GET":
        method = "POST"
    try:
        proto, dummy, host, path = url.split("/", 3)
    except ValueError:
        proto, dummy, host = url.split("/", 2)
        path = ""
    if proto != "http:":
        raise ValueError("Unsupported protocol: " + proto)

    ai = usocket.getaddrinfo(host, 80)
    addr = ai[0][4]
    s = usocket.socket()
    s.connect(addr)
    if data:
        req = b"%s /%s HTTP/1.0\r\nHost: %s\r\nContent-Length: %d\r\n\r\n" % (method, path, host, len(data))
    else:
        req = b"%s /%s HTTP/1.0\r\nHost: %s\r\n\r\n" % (method, path, host)
    s.send(req)
    if data:
        s.send(data)

    l = s.readline()
    protover, status, msg = l.split(None, 2)
    status = int(status)
    #print(protover, status, msg)
    while True:
        l = s.readline()
        if not l or l == b"\r\n":
            break
        #print(line)
        if l.startswith(b"Transfer-Encoding:"):
            if b"chunked" in line:
                raise ValueError("Unsupported " + l)
        elif l.startswith(b"Location:"):
            raise NotImplementedError("Redirects not yet supported")

    return s



from urllib.urequest import urlopen


class Xively:

    def __init__(self, feed, key):
        self.url = "http://api.xively.com/v2/feeds/%s.json?key=%s" % (feed, key)

    def write(self, channel, value):
        data="""\
{
  "version": "1.0.0",
   "datastreams" : [ {
        "id" : "%s",
        "current_value" : "%s"
    }
  ]
}
""" % (channel, value)
        f = urlopen(self.url, method="PUT", data=data)
        resp = f.read()
        f.close()
        assert resp == b""
